api.reputation.v1.test_helpers.role package — Argus-Toolbelt 1.0 documentation

# api.reputation.v1.test_helpers.role package

## Submodules

## api.reputation.v1.test_helpers.role.add_new_role module

`api.reputation.v1.test_helpers.role.add_new_role.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role, respond with HTTP 403

`api.reputation.v1.test_helpers.role.add_new_role.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role, respond with HTTP 404

`api.reputation.v1.test_helpers.role.add_new_role.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role, respond with HTTP 200

`api.reputation.v1.test_helpers.role.add_new_role.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role, respond with HTTP 401

## api.reputation.v1.test_helpers.role.delete_role module

`api.reputation.v1.test_helpers.role.delete_role.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.role.delete_role.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.role.delete_role.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.role.delete_role.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 401

## api.reputation.v1.test_helpers.role.get_role_by_alias module

`api.reputation.v1.test_helpers.role.get_role_by_alias.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.role.get_role_by_alias.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.role.get_role_by_alias.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.role.get_role_by_alias.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 401

## api.reputation.v1.test_helpers.role.get_role_by_id module

`api.reputation.v1.test_helpers.role.get_role_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.role.get_role_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.role.get_role_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.role.get_role_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 401

## api.reputation.v1.test_helpers.role.list_roles module

`api.reputation.v1.test_helpers.role.list_roles.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role, respond with HTTP 403

`api.reputation.v1.test_helpers.role.list_roles.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role, respond with HTTP 404

`api.reputation.v1.test_helpers.role.list_roles.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role, respond with HTTP 200

`api.reputation.v1.test_helpers.role.list_roles.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role, respond with HTTP 401

## api.reputation.v1.test_helpers.role.search_roles module

`api.reputation.v1.test_helpers.role.search_roles.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/search, respond with HTTP 403

`api.reputation.v1.test_helpers.role.search_roles.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/search, respond with HTTP 404

`api.reputation.v1.test_helpers.role.search_roles.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/search, respond with HTTP 200

`api.reputation.v1.test_helpers.role.search_roles.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/search, respond with HTTP 401

## api.reputation.v1.test_helpers.role.update_role module

`api.reputation.v1.test_helpers.role.update_role.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 403

`api.reputation.v1.test_helpers.role.update_role.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 404

`api.reputation.v1.test_helpers.role.update_role.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 200

`api.reputation.v1.test_helpers.role.update_role.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/reputation/v1/role/w+, respond with HTTP 401

## Module contents